@@ -1,3 +1,3 @@
-import NeuralNetworks
+from NeuralNetworks import *
 from BaseNeuralNetwork import *
 from utils import *
